..
   Copyright (C) 2014 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Utility functions
=================

.. currentmodule:: bayespy.utils

.. autosummary::
   :toctree: generated/

   linalg
   random
   optimize
   misc
